@@ -7,11 +7,10 @@ test_that("ma_search works as expected", {
     aa <- ma_search(query = "Y='19'...")
 
     expect_is(aa, "tbl_df")
-    # expect_named(aa, c('logprob', 'Id', 'Ti', 'Y', 'CC', 'AA', 'J.JN',
-    #                    'DN', 'VFN', 'DOI'))
-
     expect_type(aa$logprob, "double")
     expect_type(aa$Id, "double")
-    expect_type(aa$VFN, "character")
+    expect_type(aa$AA, "list")
+    expect_is(aa$AA[[1]], "data.frame")
+    expect_named(aa$AA[[1]], "AuN")
   }, preserve_exact_body_bytes = TRUE)
 })
